@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2019 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2020 V.A. Sole, European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -505,6 +505,8 @@ class QNexusWidget(qt.QWidget):
             # handle a right click on a group or a dataset of string type
             _hdf5WidgetDatasetMenu.addAction(QString("Show Information"),
                                              self._showInfoWidgetSlot)
+            _hdf5WidgetDatasetMenu.addAction(QString("Copy Path to Clipboard"),
+                                             self._copyPathSlot)
             _hdf5WidgetDatasetMenu.exec_(qt.QCursor.pos())
         else:
             #handle a right click on a numeric dataset
@@ -520,6 +522,8 @@ class QNexusWidget(qt.QWidget):
             else:
                 _hdf5WidgetDatasetMenu.addAction(QString("Show Information"),
                                                  self._showInfoWidgetSlot)
+                _hdf5WidgetDatasetMenu.addAction(QString("Copy Path to Clipboard"),
+                                             self._copyPathSlot)
                 _hdf5WidgetDatasetMenu.exec_(qt.QCursor.pos())
         self._lastItemDict = None
         return
@@ -542,6 +546,15 @@ class QNexusWidget(qt.QWidget):
                                    ddict['name'],
                                    dset=is_numeric_dataset)
 
+    def _copyPathSlot(self, ddict=None):
+        if ddict is None:
+            ddict = self._lastItemDict
+        try:
+            clipboard = qt.QApplication.clipboard()
+            clipboard.setText(ddict["name"])
+        except:
+            _logger.warning("Unsuccessful copy to clipboard")
+
     def _openDataset(self, ddict=None):
         if ddict is None:
             ddict = self._lastItemDict
@@ -899,7 +912,7 @@ class QNexusWidget(qt.QWidget):
                 phynxFile  = self.data._sourceObjectList[fileIndex]
                 entryIndex = list(phynxFile["/"].keys()).index(entry[1:])
                 sel['Key']        = "%d.%d" % (fileIndex+1, entryIndex+1)
-                sel['legend']     = os.path.basename(sel['SourceName'][0])+\
+                sel['legend']     = os.path.basename(filename)+\
                                     " " + posixpath.basename(entry) #it was sel['Key']
                 sel['selection'] = {}
                 sel['selection']['sourcename'] = filename
@@ -930,7 +943,7 @@ class QNexusWidget(qt.QWidget):
                 else:
                     entryIndex = list(phynxFile["/"].keys()).index(entry[1:])
                 sel['Key']        = "%d.%d" % (fileIndex+1, entryIndex+1)
-                sel['legend']     = os.path.basename(sel['SourceName'][0])+\
+                sel['legend']     = os.path.basename(filename)+\
                                     " " + posixpath.basename(entry) #it was sel['Key']
                 sel['selection'] = {}
                 sel['selection']['sourcename'] = filename
